==> objenesis_2.5.1.orig.tar.gz: objenesis-2.5.1/main/src/test/java/org/objenesis/ObjenesisExceptionTest.java <==
/**
 * Copyright 2006-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.objenesis;

import static org.junit.Assert.*;

import org.junit.Test;

/**
 * @author Henri Tremblay
 */
public class ObjenesisExceptionTest {

   @Test
   public final void testObjenesisExceptionString() {
      Exception e = new ObjenesisException("test");
      assertEquals("test", e.getMessage());
   }

   @Test
   public final void testObjenesisExceptionThrowable() {
      Exception cause = new RuntimeException("test");
      Exception e = new ObjenesisException(cause);
      assertSame(cause, e.getCause());
      assertEquals(cause.toString(), e.getMessage());

      // Check null case
      e = new ObjenesisException((Throwable) null);
      assertNull(e.getCause());
      assertEquals(null, e.getMessage());
   }

   @Test
   public final void testObjenesisExceptionStringThrowable() {
      Exception cause = new RuntimeException("test");
      Exception e = new ObjenesisException("msg", cause);
      assertSame(cause, e.getCause());
      assertEquals("msg", e.getMessage());

      // Check null case
      e = new ObjenesisException("test", null);
      assertNull(e.getCause());
      assertEquals("test", e.getMessage());
   }

}

==> objenesis_3.0.1.orig.tar.gz: objenesis-3.0.1/main/src/test/java/org/objenesis/ObjenesisExceptionTest.java <==
/*
 * Copyright 2006-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.objenesis;

import static org.junit.Assert.*;

import org.junit.Test;

/**
 * @author Henri Tremblay
 */
public class ObjenesisExceptionTest {

   @Test
   public final void testObjenesisExceptionString() {
      Exception e = new ObjenesisException("test");
      assertEquals("test", e.getMessage());
   }

   @Test
   public final void testObjenesisExceptionThrowable() {
      Exception cause = new RuntimeException("test");
      Exception e = new ObjenesisException(cause);
      assertSame(cause, e.getCause());
      assertEquals(cause.toString(), e.getMessage());

      // Check null case
      e = new ObjenesisException((Throwable) null);
      assertNull(e.getCause());
      assertNull(e.getMessage());
   }

   @Test
   public final void testObjenesisExceptionStringThrowable() {
      Exception cause = new RuntimeException("test");
      Exception e = new ObjenesisException("msg", cause);
      assertSame(cause, e.getCause());
      assertEquals("msg", e.getMessage());

      // Check null case
      e = new ObjenesisException("test", null);
      assertNull(e.getCause());
      assertEquals("test", e.getMessage());
   }

}
